@@ -1600,6 +1600,8 @@ def check_yml_file(yml_fp, yml_type, version_fp=None, execute=False,
             yml_changed = True
         else:
             return yml_fp
+    print("changed?", yml_changed)
+    print(yml_d)
     for key in list(yml_d.keys()):  # NB: list needed because otherwise keys cannot be deleted!
         
         # check if all keys have the prefix of the yml type (..#AUTH, ..#BOOK, ..#VERS):
